aboutsummaryrefslogtreecommitdiff
path: root/engines/agos/sound.cpp
diff options
context:
space:
mode:
authorEugene Sandulenko2006-09-29 09:44:30 +0000
committerEugene Sandulenko2006-09-29 09:44:30 +0000
commitbb1547ab1ce3eb0a586814949e59864888f99c83 (patch)
tree66e780855ef521dab3cfc5dcaad8e3d90f764f00 /engines/agos/sound.cpp
parentabf4ede05ba070478cf942817140a6744015dfab (diff)
downloadscummvm-rg350-bb1547ab1ce3eb0a586814949e59864888f99c83.tar.gz
scummvm-rg350-bb1547ab1ce3eb0a586814949e59864888f99c83.tar.bz2
scummvm-rg350-bb1547ab1ce3eb0a586814949e59864888f99c83.zip
Phase 5 of Simon engine renaming. Renamed namespace Simon -> AGOS and
SimonEngine -> AGOSEngine. Source is compilable and runnable again. I'm done. svn-id: r24013
Diffstat (limited to 'engines/agos/sound.cpp')
-rw-r--r--engines/agos/sound.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/engines/agos/sound.cpp b/engines/agos/sound.cpp
index 42c2df1723..5af4340804 100644
--- a/engines/agos/sound.cpp
+++ b/engines/agos/sound.cpp
@@ -39,7 +39,7 @@
using Common::File;
-namespace Simon {
+namespace AGOS {
#define SOUND_BIG_ENDIAN true
@@ -252,7 +252,7 @@ void FlacSound::playSound(uint sound, Audio::SoundHandle *handle, byte flags)
}
#endif
-Sound::Sound(SimonEngine *vm, const GameSpecificSettings *gss, Audio::Mixer *mixer)
+Sound::Sound(AGOSEngine *vm, const GameSpecificSettings *gss, Audio::Mixer *mixer)
: _vm(vm), _mixer(mixer) {
_voice = 0;
_effects = 0;
@@ -711,4 +711,4 @@ void Sound::switchVoiceFile(const GameSpecificSettings *gss, uint disc) {
}
}
-} // End of namespace Simon
+} // End of namespace AGOS